==> uportal__open-id-connect-1.3.0.jar: META-INF/resources/webjars/uportal__open-id-connect/1.3.0/cjs/open-id-connect.js <==
"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = openIdConnect;
exports.tokenize = tokenize;

require("core-js/modules/es7.symbol.async-iterator");

require("core-js/modules/es6.symbol");

require("core-js/modules/es6.array.iterator");

require("core-js/modules/es7.object.entries");

require("core-js/modules/web.dom.iterable");

require("regenerator-runtime/runtime");

require("core-js/modules/es6.promise");

var _axios = require("axios");

var _jwtDecode = _interopRequireDefault(require("jwt-decode"));

require("babel-polyfill");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _slicedToArray(arr, i) { return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _nonIterableRest(); }

function _nonIterableRest() { throw new TypeError("Invalid attempt to destructure non-iterable instance"); }

function _iterableToArrayLimit(arr, i) { var _arr = []; var _n = true; var _d = false; var _e = undefined; try { for (var _i = arr[Symbol.iterator](), _s; !(_n = (_s = _i.next()).done); _n = true) { _arr.push(_s.value); if (i && _arr.length === i) break; } } catch (err) { _d = true; _e = err; } finally { try { if (!_n && _i["return"] != null) _i["return"](); } finally { if (_d) throw _e; } } return _arr; }

function _arrayWithHoles(arr) { if (Array.isArray(arr)) return arr; }

function _asyncToGenerator(fn) { return function () { var self = this, args = arguments; return new Promise(function (resolve, reject) { var gen = fn.apply(self, args); function step(key, arg) { try { var info = gen[key](arg); var value = info.value; } catch (error) { reject(error); return; } if (info.done) { resolve(value); } else { Promise.resolve(value).then(_next, _throw); } } function _next(value) { step("next", value); } function _throw(err) { step("throw", err); } _next(); }); }; }

// needed to apply async/await polyfills
var token = null;
/**
 * Options for getting tokens
 * @typedef {Object} Options
 * @property {string} [userInfoApiUrl] - url to Open ID Connect endpoint
 * @property {number} [timeout] - time in milliseconds until token will be
 *                                invalid
 * @property {Object} [propertyTransforms] - apply additional transforms to
 *                                           specific properties
 */

/**
 * Callback to resolve Open ID Connect token
 * @callback tokenCallback
 * @param {?Error} err -
 * @param {?Object} token - with encoded and decoded values
 */

/**
 * Get token from uPortal Open ID Connect service
 * @param {Options} [options] - allow setting a custom user info API url and a
 *                              custom clock smear
 * @param {tokenCallback} [callback] - optional callback, alternative to Promise
 *                                     API
 * @return {Promise<Object>} Promise that resolves with the encoded and decoded
 *                           token in an Object
 */

function openIdConnect() {
  return _openIdConnect.apply(this, arguments);
}
/**
 * Extract JWT contents
 * @param {string} jwt - JSON Web Token to decode
 * @return {Object} with encoded and decoded values
 */


function _openIdConnect() {
  _openIdConnect = _asyncToGenerator(
  /*#__PURE__*/
  regeneratorRuntime.mark(function _callee() {
    var _ref,
        _ref$userInfoApiUrl,
        userInfoApiUrl,
        _ref$timeout,
        timeout,
        _ref$propertyTransfor,
        propertyTransforms,
        callback,
        _ref2,
        data,
        _args = arguments;

    return regeneratorRuntime.wrap(function _callee$(_context) {
      while (1) {
        switch (_context.prev = _context.next) {
          case 0:
            _ref = _args.length > 0 && _args[0] !== undefined ? _args[0] : {}, _ref$userInfoApiUrl = _ref.userInfoApiUrl, userInfoApiUrl = _ref$userInfoApiUrl === void 0 ? '/uPortal/api/v5-1/userinfo' : _ref$userInfoApiUrl, _ref$timeout = _ref.timeout, timeout = _ref$timeout === void 0 ? 50000 : _ref$timeout, _ref$propertyTransfor = _ref.propertyTransforms, propertyTransforms = _ref$propertyTransfor === void 0 ? {} : _ref$propertyTransfor;
            callback = _args.length > 1 ? _args[1] : undefined;

            if (!(token !== null)) {
              _context.next = 4;
              break;
            }

            return _context.abrupt("return", token);

          case 4:
            _context.prev = 4;
            _context.next = 7;
            return (0, _axios.get)(userInfoApiUrl, {
              responseType: 'text',
              withCredentials: true
            });

          case 7:
            _ref2 = _context.sent;
            data = _ref2.data;
            // store the encoded and decoded versions
            token = tokenize(data); // Allow for additional transforms to be applied to decoded properties

            Object.entries(propertyTransforms).forEach(function (_ref3) {
              var _ref4 = _slicedToArray(_ref3, 2),
                  property = _ref4[0],
                  transform = _ref4[1];

              token.decoded[property] = transform(token.decoded[property]);
            }); // automatically clear token after expiration

            setTimeout(function () {
              token = null;
            }, timeout); // pass value to optional call back

            if (!callback) {
              _context.next = 14;
              break;
            }

            return _context.abrupt("return", callback(null, token));

          case 14:
            return _context.abrupt("return", token);

          case 17:
            _context.prev = 17;
            _context.t0 = _context["catch"](4);

            if (!callback) {
              _context.next = 21;
              break;
            }

            return _context.abrupt("return", callback(_context.t0));

          case 21:
            throw _context.t0;

          case 22:
          case "end":
            return _context.stop();
        }
      }
    }, _callee, this, [[4, 17]]);
  }));
  return _openIdConnect.apply(this, arguments);
}

function tokenize(jwt) {
  return {
    encoded: jwt,
    decoded: (0, _jwtDecode.default)(jwt)
  };
}

==> uportal__open-id-connect-1.3.1.jar: META-INF/resources/webjars/uportal__open-id-connect/1.3.1/cjs/open-id-connect.js <==
"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = openIdConnect;
exports.tokenize = tokenize;

var _axios = require("axios");

var _jwtDecode = _interopRequireDefault(require("jwt-decode"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _slicedToArray(arr, i) { return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _nonIterableRest(); }

function _nonIterableRest() { throw new TypeError("Invalid attempt to destructure non-iterable instance"); }

function _iterableToArrayLimit(arr, i) { var _arr = []; var _n = true; var _d = false; var _e = undefined; try { for (var _i = arr[Symbol.iterator](), _s; !(_n = (_s = _i.next()).done); _n = true) { _arr.push(_s.value); if (i && _arr.length === i) break; } } catch (err) { _d = true; _e = err; } finally { try { if (!_n && _i["return"] != null) _i["return"](); } finally { if (_d) throw _e; } } return _arr; }

function _arrayWithHoles(arr) { if (Array.isArray(arr)) return arr; }

function asyncGeneratorStep(gen, resolve, reject, _next, _throw, key, arg) { try { var info = gen[key](arg); var value = info.value; } catch (error) { reject(error); return; } if (info.done) { resolve(value); } else { Promise.resolve(value).then(_next, _throw); } }

function _asyncToGenerator(fn) { return function () { var self = this, args = arguments; return new Promise(function (resolve, reject) { var gen = fn.apply(self, args); function _next(value) { asyncGeneratorStep(gen, resolve, reject, _next, _throw, "next", value); } function _throw(err) { asyncGeneratorStep(gen, resolve, reject, _next, _throw, "throw", err); } _next(undefined); }); }; }

var token = null;
/**
 * Options for getting tokens
 * @typedef {Object} Options
 * @property {string} [userInfoApiUrl] - url to Open ID Connect endpoint
 * @property {number} [timeout] - time in milliseconds until token will be
 *                                invalid
 * @property {Object} [propertyTransforms] - apply additional transforms to
 *                                           specific properties
 */

/**
 * Callback to resolve Open ID Connect token
 * @callback tokenCallback
 * @param {?Error} err -
 * @param {?Object} token - with encoded and decoded values
 */

/**
 * Get token from uPortal Open ID Connect service
 * @param {Options} [options] - allow setting a custom user info API url and a
 *                              custom clock smear
 * @param {tokenCallback} [callback] - optional callback, alternative to Promise
 *                                     API
 * @return {Promise<Object>} Promise that resolves with the encoded and decoded
 *                           token in an Object
 */

function openIdConnect() {
  return _openIdConnect.apply(this, arguments);
}
/**
 * Extract JWT contents
 * @param {string} jwt - JSON Web Token to decode
 * @return {Object} with encoded and decoded values
 */


function _openIdConnect() {
  _openIdConnect = _asyncToGenerator(
  /*#__PURE__*/
  regeneratorRuntime.mark(function _callee() {
    var _ref,
        _ref$userInfoApiUrl,
        userInfoApiUrl,
        _ref$timeout,
        timeout,
        _ref$propertyTransfor,
        propertyTransforms,
        callback,
        _ref2,
        data,
        _args = arguments;

    return regeneratorRuntime.wrap(function _callee$(_context) {
      while (1) {
        switch (_context.prev = _context.next) {
          case 0:
            _ref = _args.length > 0 && _args[0] !== undefined ? _args[0] : {}, _ref$userInfoApiUrl = _ref.userInfoApiUrl, userInfoApiUrl = _ref$userInfoApiUrl === void 0 ? '/uPortal/api/v5-1/userinfo' : _ref$userInfoApiUrl, _ref$timeout = _ref.timeout, timeout = _ref$timeout === void 0 ? 50000 : _ref$timeout, _ref$propertyTransfor = _ref.propertyTransforms, propertyTransforms = _ref$propertyTransfor === void 0 ? {} : _ref$propertyTransfor;
            callback = _args.length > 1 ? _args[1] : undefined;

            if (!(token !== null)) {
              _context.next = 4;
              break;
            }

            return _context.abrupt("return", token);

          case 4:
            _context.prev = 4;
            _context.next = 7;
            return (0, _axios.get)(userInfoApiUrl, {
              responseType: 'text',
              withCredentials: true
            });

          case 7:
            _ref2 = _context.sent;
            data = _ref2.data;
            // store the encoded and decoded versions
            token = tokenize(data); // Allow for additional transforms to be applied to decoded properties

            Object.entries(propertyTransforms).forEach(function (_ref3) {
              var _ref4 = _slicedToArray(_ref3, 2),
                  property = _ref4[0],
                  transform = _ref4[1];

              token.decoded[property] = transform(token.decoded[property]);
            }); // automatically clear token after expiration

            setTimeout(function () {
              token = null;
            }, timeout); // pass value to optional call back

            if (!callback) {
              _context.next = 14;
              break;
            }

            return _context.abrupt("return", callback(null, token));

          case 14:
            return _context.abrupt("return", token);

          case 17:
            _context.prev = 17;
            _context.t0 = _context["catch"](4);

            if (!callback) {
              _context.next = 21;
              break;
            }

            return _context.abrupt("return", callback(_context.t0));

          case 21:
            throw _context.t0;

          case 22:
          case "end":
            return _context.stop();
        }
      }
    }, _callee, this, [[4, 17]]);
  }));
  return _openIdConnect.apply(this, arguments);
}

function tokenize(jwt) {
  return {
    encoded: jwt,
    decoded: (0, _jwtDecode.default)(jwt)
  };
}
